@@ -10,7 +10,7 @@
 #' @param .prefix Prefix to be added to function names.
 #'
 #' @details `rules()` repairs names by the following algorithm:
-#' - Absent names are replaced with the 'rule__\\{ind\\}' where \\{ind\\} is the
+#' - Absent names are replaced with the `'rule__{ind}'` where `{ind}` is the
 #'   index of function position in the `...` .
 #' - `.prefix` is added at the beginning of all names. The default is `._.` . It
 #'   is picked for its symbolism (it is the Morse code of letter 'R') and rare
@@ -33,7 +33,9 @@
 rules <- function(..., .prefix = "._.") {
   dots <- quos(...)
   names(dots) <- enhance_names(
-    .name = rlang::names2(dots), .prefix = .prefix, .root = "rule"
+    .name = rlang::names2(dots),
+    .prefix = .prefix,
+    .root = "rule"
   )
 
   lapply(dots, extract_funs_input)
@@ -59,7 +61,9 @@ extract_funs_input <- function(obj) {
     expr
   } else {
     stop(
-      "Wrong input `", rlang::expr_text(expr), "` to `rules()`.",
+      "Wrong input `",
+      rlang::expr_text(expr),
+      "` to `rules()`.",
       call. = FALSE
     )
   }
