@@ -8,18 +8,34 @@ df <- mtcars
 # inside_punct ------------------------------------------------------------
 test_that("inside_punct works", {
   input1 <- c(
-    "._.", "._.a", "a._.", "a._.a",
-    "a_._.a", "a._._a", "a_._._a",
-    "a__._._a", "a_._.__a", "a__._.__a",
-    "._.*_.", "._.._.",
-    "__.a", ".__a", "...", "a_a"
+    "._.",
+    "._.a",
+    "a._.",
+    "a._.a",
+    "a_._.a",
+    "a._._a",
+    "a_._._a",
+    "a__._._a",
+    "a_._.__a",
+    "a__._.__a",
+    "._.*_.",
+    "._.._.",
+    "__.a",
+    ".__a",
+    "...",
+    "a_a"
   )
 
   expect_identical(grep(inside_punct(), input1), 1:12)
 
   input2 <- c(
-    "a", "_a", "a_", "_a_",
-    "__a", "a__", "__a__",
+    "a",
+    "_a",
+    "a_",
+    "_a_",
+    "__a",
+    "a__",
+    "__a__",
     "_"
   )
 
